@@ -1317,3 +1317,49 @@ class CryptoRatesExtension(Extension):
     def parse(self, parser):
         lineno = next(parser.stream).lineno
         return CallBlock(self.call_method("_render", []), [], [], '').set_lineno(lineno)
+
+
+class SidebarExtension(Extension):
+    tags = set(['sidebar'])
+
+    def __init__(self, environment):
+        super(SidebarExtension, self).__init__(environment)
+
+    def _render(self, args, caller=None):
+        logger.info('sidebar Args: {0}'.format(args))
+
+        default = ['casinos', 3, 10, 'Online Casinos']
+        _ca = len(default)
+        args = args[:_ca] + default[len(args):] + args[_ca:]
+
+        _service = args[0]
+        _primary = int(args[1])
+        _secondary = int(args[2])
+        _title = args[3]
+
+        _total = _primary + _secondary
+
+        _items, _count = Page.provider_by_context(
+            country=current_user.country_full,
+            is_searchable=True,
+            is_redirect=False,
+            services=_service,
+            _source=["title", "alias", "logo", "path", "logo_small", "ref_link", "welcome_package", "welcome_package_note"],
+            _locale=g.language,
+            _count=_total,
+        )
+
+        logger.info(f'We found {_count} items for sidebar')    
+
+        t = current_app.jinja_env.get_template('_ext-sidebar.html')
+        return t.render(items=_items, service=_service, primary=_primary, total=_total, title=_title)
+
+    def parse(self, parser):
+        lineno = next(parser.stream).lineno
+
+        args = []
+        while parser.stream.current.type != 'block_end':
+            args.append(parser.parse_expression())
+            parser.stream.skip_if('comma')
+
+        return CallBlock(self.call_method("_render", args=[List(args)]), [], [], []).set_lineno(lineno)          
